package com.huatek.busi.mapper;

import com.huatek.busi.dto.RMasterDataRecordDto;
import com.huatek.busi.entity.RMasterData;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

@Repository
public interface RMasterDataRecordMapper {
    RMasterDataRecordDto getRMasterDataRecord(RMasterData rMasterData);
    int delete(@Param("refId") String refId);
    int deleteBatch(@Param("refIds") List<String> refIds);

    RMasterDataRecordDto getRBLQDataRecord(RMasterData rMasterData);

    RMasterDataRecordDto getRKGGDataRecord(RMasterData rMasterData);

    RMasterDataRecordDto getRGENDataRecord(RMasterData rMasterData);

    RMasterDataRecordDto getRCableDataRecord(RMasterData rMasterData);

    int deleteBlq(@Param("refId") String refId);

    int deleteKgg(@Param("refId") String refId);

    int deleteGen(@Param("refId") String refId);

    int deleteDl(@Param("refId") String refId);

    int deleteBlqBatch(@Param("refIds") List<String> refIds);

    int deleteKggBatch(@Param("refIds") List<String> refIds);

    int deleteGenBatch(@Param("refIds") List<String> refIds);

    int deleteDlBatch(@Param("refIds") List<String> refIds);
}
